==> libopenshot-audio-docs-0.3.0-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "OpenShot Audio Library | OpenShotAudio", "index.html", [
    [ "The OpenShot Audio Library", "index.html", [
      [ "Getting Started", "index.html#autotoc_md1", null ],
      [ "Build Tools", "index.html#autotoc_md2", null ],
      [ "Dependencies", "index.html#autotoc_md3", [
        [ "Build dependencies", "index.html#autotoc_md4", [
          [ "CMake", "index.html#autotoc_md5", null ]
        ] ],
        [ "Documentation dependencies", "index.html#autotoc_md6", [
          [ "Doxygen", "index.html#autotoc_md7", null ]
        ] ],
        [ "OS-specific dependencies", "index.html#autotoc_md8", [
          [ "ALSA - Required, Linux only", "index.html#autotoc_md9", null ],
          [ "ASIO SDK - Optional, Windows only", "index.html#autotoc_md10", null ]
        ] ]
      ] ],
      [ "Obtaining Source Code", "index.html#autotoc_md11", null ],
      [ "Linux Build Instructions (libopenshot-audio)", "index.html#autotoc_md12", null ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", null ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a8442bfdc68c5dbf4e1a6693ff9b61896",
"classjuce_1_1AudioProcessLoadMeasurer.html",
"classjuce_1_1CharPointer__UTF16.html#a6422c90ef9c521a55eba6f303e30e6a6",
"classjuce_1_1File.html#a01aa22f7ebb9b06840c2118a5e99964a",
"classjuce_1_1IIRCoefficients.html",
"classjuce_1_1MPEInstrument.html#a41a654610f46359202f9ecf3ee0cbbf8",
"classjuce_1_1MidiBuffer.html#ade4e9d5b4ca396e94c03d3370972b77c",
"classjuce_1_1NamedPipe.html#a9af215d2dd492dc72d7027e029bc74b3",
"classjuce_1_1ReadWriteLock.html#a9668721cf0be4b64da52f71ecba9820d",
"classjuce_1_1SortedSet.html#aadc4aee7c8854ead9f7b9276189dc309",
"classjuce_1_1StringArray.html#aac7ba501945605961549f6fee1286625",
"classjuce_1_1ThreadPoolJob.html#aff1ded5a73f7e20a65fad92bb62f7c53",
"classjuce_1_1ValueTree.html#a8e50d4669c64ea66bdf406cd160884be",
"classjuce_1_1dsp_1_1AudioBlock.html#a4ae2c15be9dc8d00bf3b5ebcc7e49a80",
"classjuce_1_1var.html#a5d205a32b1448993c1525ed4280759f7",
"juce__ConsoleApplication_8cpp_source.html",
"juce__TargetPlatform_8h_source.html",
"structjuce_1_1MPESynthesiserBase.html#ac43f7a6087ee7b92798d3d4a3ba21241"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> libopenshot-audio-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "OpenShot Audio Library | OpenShotAudio", "index.html", [
    [ "The OpenShot Audio Library", "index.html", "index" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", null ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a8442bfdc68c5dbf4e1a6693ff9b61896",
"classjuce_1_1AudioProcessLoadMeasurer.html",
"classjuce_1_1CharPointer__UTF16.html#a6422c90ef9c521a55eba6f303e30e6a6",
"classjuce_1_1File.html#a01aa22f7ebb9b06840c2118a5e99964a",
"classjuce_1_1IIRCoefficients.html",
"classjuce_1_1MPEInstrument.html#a41a654610f46359202f9ecf3ee0cbbf8",
"classjuce_1_1MidiBuffer.html#ade4e9d5b4ca396e94c03d3370972b77c",
"classjuce_1_1NamedPipe.html#a9af215d2dd492dc72d7027e029bc74b3",
"classjuce_1_1ReadWriteLock.html#a9668721cf0be4b64da52f71ecba9820d",
"classjuce_1_1SortedSet.html#aadc4aee7c8854ead9f7b9276189dc309",
"classjuce_1_1StringArray.html#aac7ba501945605961549f6fee1286625",
"classjuce_1_1ThreadPoolJob.html#aff1ded5a73f7e20a65fad92bb62f7c53",
"classjuce_1_1ValueTree.html#a8e50d4669c64ea66bdf406cd160884be",
"classjuce_1_1dsp_1_1AudioBlock.html#a4ae2c15be9dc8d00bf3b5ebcc7e49a80",
"classjuce_1_1var.html#a5d205a32b1448993c1525ed4280759f7",
"juce__ConsoleApplication_8cpp_source.html",
"juce__TargetPlatform_8h_source.html",
"structjuce_1_1MPESynthesiserBase.html#ac43f7a6087ee7b92798d3d4a3ba21241"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
